@@ -1,14 +1,17 @@
 # a.voss@fh-aachen.de
 
-import __version__
+#import __version__
+#from __version__ import __version__
+
+import version.__version__
 
 
-def version(n: int) -> str:
-    return f"{__version__.__version__}-{n}"
+def version_n(n: int) -> str:
+    return f"{version.__version__.__version__}-{n}"
 
 
 if __name__ == "__main__":
-    print(f"Version: {version(25)}")
+    print(f"Version: {version_n(25)}")
 
 
 """
@@ -29,4 +32,6 @@ python3 -m twine upload dist/*
 python3 -m pip install cbl_test_package==1.2.3 
 pip install cbl-test-package==1.2.3
 pip install cbl-test-package==2.3.4
+
+pip install cbl_tools
 """
