@@ -1,12 +1,15 @@
 # a.voss@fh-aachen.de
 
+#import __version__
+from __version__ import __version__
+
 
 def version(n: int) -> str:
-    return f"2.3.4-{n}"  # same as in pyproject.toml
+    return f"{__version__}-{n}"
 
 
 if __name__ == "__main__":
-    print(f"Version 23: {version(23)}")
+    print(f"Version: {version(25)}")
 
 
 """
@@ -20,10 +23,13 @@ python3 -m build
 python3 -m twine upload --repository testpypi dist/* 
 python3 -m pip install --index-url https://test.pypi.org/simple/ --no-deps cbl_test_package@1.2.3 
 
+https://packaging.python.org/en/latest/tutorials/packaging-projects/
 
 python3 -m build  
 python3 -m twine upload dist/* 
 python3 -m pip install cbl_test_package==1.2.3 
 pip install cbl-test-package==1.2.3
 pip install cbl-test-package==2.3.4
+
+pip install cbl_tools
 """
